package
Version:
v0.0.0-...-49f637e
Opens a new window with list of versions in this module.
Published: Aug 18, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Message struct {
Name string `json:"name"`
Content string `json:"content"`
Timestamp string `json:"timestamp"`
}
type Pagination struct {
}
type Post struct {
Id int `json:"id"`
Text string `json:"text"`
User int `json:"user"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.